@@ -18,9 +18,10 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
+
+#include <config.h>
+
+#include <glib/gi18n.h>
 
 #include "favorites.h"
 #include "proctable.h"
@@ -56,7 +57,9 @@ add_single_to_blacklist (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *it
 	ProcInfo *info = NULL;
 	
 	gtk_tree_model_get (model, iter, COL_POINTER, &info, -1);
-	g_return_if_fail (info);
+	
+	if (!info)
+		return;
 	
 	add_to_blacklist (procdata, info->name);
 	
@@ -72,7 +75,7 @@ remove_all_of_same_name_from_tree (ProcInfo *info, ProcData *procdata)
 	while (list) {
 		ProcInfo *tmp = list->data;
 		
-		if (g_strcasecmp (info->name, tmp->name) == 0) 
+		if (g_ascii_strcasecmp (info->name, tmp->name) == 0) 
 			remove_info_from_tree (tmp, procdata);
 			
 		list = g_list_next (list);
@@ -103,7 +106,7 @@ remove_from_blacklist (ProcData *procdata, gchar *name)
 	GList *list = procdata->blacklist;
 	
 	while (list) {
-		if (!g_strcasecmp (list->data, name)) {
+		if (!g_ascii_strcasecmp (list->data, name)) {
 			procdata->blacklist = g_list_remove (procdata->blacklist, list->data);
 			procdata->blacklist_num --;
 			return;
@@ -127,7 +130,7 @@ is_process_blacklisted (ProcData *procdata, gchar *name)
 	while (list)
 	{
 		gchar *process = list->data;
-		if (!g_strcasecmp (process, name))
+		if (!g_ascii_strcasecmp (process, name))
 			return TRUE;
 		
 		list = g_list_next (list);
@@ -270,7 +273,7 @@ insert_all_of_same_name_from_tree (gchar *name, ProcData *procdata)
 	while (list) {
 		ProcInfo *tmp = list->data;
 		
-		if (g_strcasecmp (name, tmp->name) == 0) 
+		if (g_ascii_strcasecmp (name, tmp->name) == 0) 
 			insert_info_to_tree (tmp, procdata);
 			
 		list = g_list_next (list);
