@@ -103,9 +103,8 @@ timeouts_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer
 
 	if (g_str_equal (key, "/apps/procman/update_interval")) {
 		procdata->config.update_interval = gconf_value_get_int (value);
-		procdata->config.update_interval = CLAMP(procdata->config.update_interval,
-							 MIN_UPDATE_INTERVAL,
-							 MAX_UPDATE_INTERVAL);
+		procdata->config.update_interval = 
+			MAX (procdata->config.update_interval, 1000);
 
 		smooth_refresh_reset(procdata->smooth_refresh);
 
@@ -200,6 +199,9 @@ color_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer dat
 		gdk_color_parse (color, &procdata->config.net_out_color);
 		load_graph_get_colors(procdata->net_graph)[3] = procdata->config.net_out_color;
 	}
+	else {
+		g_assert_not_reached();
+	}
 
 	load_graph_reset_colors(procdata->cpu_graph);
 	load_graph_reset_colors(procdata->mem_graph);
@@ -229,8 +231,6 @@ procman_data_new (GConfClient *client)
 	gint swidth, sheight;
 	gint i;
 	glibtop_cpu cpu;
-	glibtop_loadavg loadavg;
-	gsize nprocs;
 
 	pd = g_new0 (ProcData, 1);
 	
@@ -245,10 +245,6 @@ procman_data_new (GConfClient *client)
 	pd->net_graph = NULL;
 	pd->disk_timeout = 0;
 
-	glibtop_get_loadavg(&loadavg);
-	nprocs = (loadavg.nr_tasks ? 1.2f * loadavg.nr_tasks : 100);
-	pd->procinfo_allocator = g_mem_chunk_create(ProcInfo, nprocs, G_ALLOC_AND_FREE);
-
 	/* username is usually 8 chars long
 	   for caching, we create chunks of 128 chars */
 	pd->users = g_string_chunk_new(128);
@@ -257,7 +253,6 @@ procman_data_new (GConfClient *client)
 
 	pd->config.width = gconf_client_get_int (client, "/apps/procman/width", NULL);
 	pd->config.height = gconf_client_get_int (client, "/apps/procman/height", NULL);
-	pd->config.show_more_info = gconf_client_get_bool (client, "/apps/procman/more_info", NULL);
 	pd->config.show_tree = gconf_client_get_bool (client, "/apps/procman/show_tree", NULL);
 	gconf_client_notify_add (client, "/apps/procman/show_tree", tree_changed_cb,
 				 pd, NULL, NULL);
@@ -379,9 +374,7 @@ procman_data_new (GConfClient *client)
 	sheight = gdk_screen_height ();
 	pd->config.width = CLAMP (pd->config.width, 50, swidth);
 	pd->config.height = CLAMP (pd->config.height, 50, sheight);
-	pd->config.update_interval = CLAMP(pd->config.update_interval,
-					   MIN_UPDATE_INTERVAL,
-					   MAX_UPDATE_INTERVAL);
+	pd->config.update_interval = MAX (pd->config.update_interval, 1000);
 	pd->config.graph_update_interval = MAX (pd->config.graph_update_interval, 250);
 	pd->config.disks_update_interval = MAX (pd->config.disks_update_interval, 1000);
 	pd->config.whose_process = CLAMP (pd->config.whose_process, 0, 2);
@@ -427,8 +420,9 @@ procman_get_tree_state (GConfClient *client, GtkWidget *tree, const gchar *prefi
 	GtkSortType order;
 	gchar *key;
 	
-	g_return_val_if_fail (tree, FALSE);
-	g_return_val_if_fail (prefix, FALSE);
+
+	g_assert(tree);
+	g_assert(prefix);
 	
 	if (!gconf_client_dir_exists (client, prefix, NULL)) 
 		return FALSE;
@@ -507,8 +501,8 @@ procman_save_tree_state (GConfClient *client, GtkWidget *tree, const gchar *pref
 	gint sort_col;
 	GtkSortType order;
 	
-	g_return_if_fail (tree);
-	g_return_if_fail (prefix);
+	g_assert(tree);
+	g_assert(prefix);
 	
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (tree));
 	if (gtk_tree_sortable_get_sort_column_id (GTK_TREE_SORTABLE (model), &sort_col,
@@ -578,7 +572,7 @@ procman_save_config (ProcData *data)
 	GConfClient *client = data->client;
 	gint width, height;
 
-	g_return_if_fail(data != NULL);
+	g_assert(data);
 		
 	procman_save_tree_state (data->client, data->tree, "/apps/procman/proctree");
 	procman_save_tree_state (data->client, data->disk_list, "/apps/procman/disktreenew");
@@ -589,7 +583,6 @@ procman_save_config (ProcData *data)
 	
 	gconf_client_set_int (client, "/apps/procman/width", data->config.width, NULL);
 	gconf_client_set_int (client, "/apps/procman/height", data->config.height, NULL);	
-	gconf_client_set_bool (client, "/apps/procman/more_info", data->config.show_more_info, NULL);
 	gconf_client_set_int (client, "/apps/procman/current_tab", data->config.current_tab, NULL);
 	
 	save_blacklist (data, client);
@@ -734,7 +727,7 @@ main (int argc, char *argv[])
 
 	init_volume_monitor (procdata);
 
-	g_return_val_if_fail(procdata->app != NULL, 1);
+	g_assert(procdata->app);
 			
  	gtk_widget_show(procdata->app);
  	
